Index: src/codegen.h |
diff --git a/src/codegen.h b/src/codegen.h |
index 53ff2e1a1a939b97be45949fab804788b6d8156c..ea202969162ca60c62e6d6ec074562780941d196 100644 |
--- a/src/codegen.h |
+++ b/src/codegen.h |
@@ -97,10 +97,10 @@ UnaryMathFunction CreateSqrtFunction(); |
class ElementsTransitionGenerator : public AllStatic { |
public: |
// If |mode| is set to DONT_TRACK_ALLOCATION_SITE, |
// |allocation_site_info_found| may be NULL. |
static void GenerateMapChangeElementsTransition(MacroAssembler* masm, |
AllocationSiteMode mode, |
- Label* allocation_site_info_found); |
+ Label* allocation_memento_found); |
static void GenerateSmiToDouble(MacroAssembler* masm, |
AllocationSiteMode mode, |
Label* fail); |
@@ -97,10 +97,10 @@ UnaryMathFunction CreateSqrtFunction(); |
public: |
// If |mode| is set to DONT_TRACK_ALLOCATION_SITE, |
- // |allocation_site_info_found| may be NULL. |
+ // |allocation_memento_found| may be NULL. |
static void GenerateMapChangeElementsTransition(MacroAssembler* masm, |
AllocationSiteMode mode, |